@@ -1,4 +1,3 @@
-import math
 import logging
 import sys
 
@@ -19,18 +18,13 @@ class MycobotCommandGenerater(DataProcessor):
             is_power_on()
             release_all_servos()
             is_controller_connected()
-            set_free_mode()
 
         # MDI mode and operation
             get_angles()
             send_angle()
             send_angles()
-            sync_send_angles() *
-            get_radians()
-            send_radians()
             get_coords()
             send_coords()
-            sync_send_coords() *
             pause()
             resume()
             stop()
@@ -77,9 +71,6 @@ class MycobotCommandGenerater(DataProcessor):
 
         # Basic
             set_basic_output() *
-
-        # Other
-            wait() *
     """
 
     def __init__(self, debug=False):
@@ -187,9 +178,7 @@ class MycobotCommandGenerater(DataProcessor):
             speed (int): 0 ~100
         """
         check_datas(joint_id=id, degree=degree, speed=speed)
-        return self._mesg(
-            Command.SEND_ANGLE, id - 1, [self._angle_to_int(degree)], speed
-        )
+        return self._mesg(Command.SEND_ANGLE, id, [self._angle_to_int(degree)], speed)
 
     # @check_parameters(Command.SEND_ANGLES)
     def send_angles(self, degrees, speed):
@@ -221,9 +210,7 @@ class MycobotCommandGenerater(DataProcessor):
             speed(int):
         """
         check_datas(speed=speed)
-        return self._mesg(
-            Command.SEND_COORD, id - 1, [self._coord_to_int(coord)], speed
-        )
+        return self._mesg(Command.SEND_COORD, id, [self._coord_to_int(coord)], speed)
 
     def send_coords(self, coords, speed, mode):
         """Send all coords
@@ -319,10 +306,10 @@ class MycobotCommandGenerater(DataProcessor):
             joint_id: Joint id 1 - 7
             encoder: The value of the set encoder.
         """
-        return self._mesg(Command.SET_ENCODER, joint_id - 1, [encoder])
+        return self._mesg(Command.SET_ENCODER, joint_id, [encoder])
 
     def get_encoder(self, joint_id):
-        return self._mesg(Command.GET_ENCODER, joint_id - 1, has_reply=True)
+        return self._mesg(Command.GET_ENCODER, joint_id, has_reply=True)
 
     def set_encoders(self, encoders, sp):
         return self._mesg(Command.SET_ENCODERS, encoders, sp)
@@ -362,19 +349,19 @@ class MycobotCommandGenerater(DataProcessor):
 
     # Servo control
     def is_servo_enable(self, servo_id):
-        return self._mesg(Command.IS_SERVO_ENABLE, servo_id - 1)
+        return self._mesg(Command.IS_SERVO_ENABLE, servo_id)
 
     def is_all_servo_enable(self):
         return self._mesg(Command.IS_ALL_SERVO_ENABLE, has_reply=True)
 
     def set_servo_data(self, servo_no, data_id, value):
-        return self._mesg(Command.SET_SERVO_DATA, servo_no - 1, data_id, value)
+        return self._mesg(Command.SET_SERVO_DATA, servo_no, data_id, value)
 
     def get_servo_data(self, servo_no, data_id):
-        return self._mesg(Command.GET_SERVO_DATA, servo_no - 1, data_id, has_reply=True)
+        return self._mesg(Command.GET_SERVO_DATA, servo_no, data_id, has_reply=True)
 
     def set_servo_calibration(self, servo_no):
-        return self._mesg(Command.SET_SERVO_CALIBRATION, servo_no - 1)
+        return self._mesg(Command.SET_SERVO_CALIBRATION, servo_no)
 
     def release_servo(self, servo_id):
         """Power off designated servo
