@@ -13,7 +13,34 @@ class MyCobot(MycobotCommandGenerater):
     """MyCobot Python API Serial communication class.
 
     Supported methods:
-        Look at parent class: `MycobotCommandGenerater`.
+
+        # Overall status
+            Look at parent class: `MycobotCommandGenerater`.
+
+        # MDI mode and operation
+            get_radians()
+            send_radians()
+            sync_send_angles() *
+            sync_send_coords() *
+            Other look at parent class: `MycobotCommandGenerater`.
+
+        # JOG mode and operation
+            Look at parent class: `MycobotCommandGenerater`.
+
+        # Running status and Settings
+            Look at parent class: `MycobotCommandGenerater`.
+
+        # Servo control
+            Look at parent class: `MycobotCommandGenerater`.
+
+        # Atom IO
+            Look at parent class: `MycobotCommandGenerater`.
+
+        # Basic
+            Look at parent class: `MycobotCommandGenerater`.
+
+        # Other
+            wait() *
     """
 
     def __init__(self, port, baudrate="115200", timeout=0.1, debug=False):
@@ -37,7 +64,7 @@ class MyCobot(MycobotCommandGenerater):
         self._serial_port.flush()
         time.sleep(0.05)
 
-    def _read(self, size=1024):
+    def _read(self):
         if self._serial_port.inWaiting() > 0:
             data = self._serial_port.read(self._serial_port.inWaiting())
             self.log.debug("_read: {}".format(data))
@@ -136,6 +163,25 @@ class MyCobot(MycobotCommandGenerater):
             time.sleep(0.1)
         return self
 
+    # Basic for raspberry pi.
+    def gpio_init(self):
+        """Init GPIO module.
+        Raspberry Pi version need this.
+        """
+        import RPi.GPIO as GPIO
+
+        GPIO.setmode(GPIO.BMC)
+        self.gpio = GPIO
+
+    def gpio_output(self, pin, v):
+        """Set GPIO output value.
+        Args:
+            pin: port number(int).
+            v: Output value(int), 1 - GPIO.HEIGH, 2 - GPIO.LOW
+        """
+        self.gpio.setup(pin, self.gpio.OUT)
+        self.gpio.setup(pin, v)
+
     # Other
     def wait(self, t):
         time.sleep(t)
